@@ -19,6 +19,9 @@
 #include <QtDBus/QDBusConnection>
 #include <QtDBus/QDBusMessage>
 #include <QtDBus/QDBusInterface>
+#include <X11/Xlib.h>
+#include <X11/Xatom.h>
+#include <QX11Info>
 #endif
 
 Controller::Controller(QObject *parent) :
@@ -41,6 +44,44 @@ void Controller::toggleState() {
     }
 }
 
+void Controller::keepDisplayOn() {
+#ifdef Q_WS_MAEMO_5
+    QDBusConnection systemDbusConnection = QDBusConnection::systemBus();
+    QDBusInterface mceConnectionInterface("com.nokia.mce",
+                                          "/com/nokia/mce/request",
+                                          "com.nokia.mce.request",
+                                          systemDbusConnection, this);
+    mceConnectionInterface.call("req_display_blanking_pause");
+#endif
+}
+
+void Controller::doNotDisturb(bool videoPlaying) {
+#ifdef Q_WS_MAEMO_5
+    Atom atom = XInternAtom(QX11Info::display() , "_HILDON_DO_NOT_DISTURB", False);
+    if (!atom) {
+        qWarning("Unable to obtain _HILDON_DO_NOT_DISTURB. This example will only work "
+                 "on a Maemo 5 device!");
+        return;
+    }
+
+    if (videoPlaying) {
+        long state = 1;
+        XChangeProperty(
+                    QX11Info::display(),
+                    m_view->winId(),
+                    atom,
+                    XA_INTEGER,
+                    32,
+                    PropModeReplace,
+                    (unsigned char *) &state,
+                    1);
+    }
+    else {
+        XDeleteProperty(QX11Info::display(), m_view->winId(), atom);
+    }
+#endif
+}
+
 QString Controller::getLanguage() const {
     QString langCode = "en";
 
@@ -113,6 +154,9 @@ void Controller::getMediaPlayerFromDB() {
         }
         //        qDebug() << player;
     }
+    if (player == "cuteTube Player") {
+        player = "Media Player";
+    }
     setMediaPlayer(player);
     db.close();
 }
@@ -160,7 +204,7 @@ bool Controller::xTubeInstalled() const {
 
 QStringList Controller::getInstalledMediaPlayers() const {
     QStringList playerList;
-    playerList << "Media Player";
+    playerList << "cuteTube Player" << "Media Player";
     if ((QFile::exists("/usr/bin/mplayer"))) {
         playerList << "MPlayer";
     }
@@ -171,8 +215,8 @@ QStringList Controller::getInstalledMediaPlayers() const {
 }
 
 void Controller::playVideo(const QString &url) {
-#ifdef Q_WS_MAEMO_5
     //    qDebug() << url;
+#ifdef Q_WS_MAEMO_5
     minimize();
     if (mediaPlayer == "mplayer") {
         QStringList args;
@@ -188,19 +232,6 @@ void Controller::playVideo(const QString &url) {
     }
     emit playbackStarted(url);
 
-#elif defined(Q_OS_SYMBIAN)
-    if (url.startsWith("http://")) {
-        QFile ytlink("c:\ytlink.ram");
-        ytlink.open(QIODevice::WriteOnly);
-        ytlink.write(url.toAscii());
-        ytlink.close();
-        QDesktopServices::openUrl(QUrl::fromLocalFile(ytlink.fileName()));
-    }
-    else {
-        QDesktopServices::openUrl(QUrl::fromLocalFile(url));
-    }
-    emit playbackStarted(url);
-
 #else
     if (url.startsWith("http://")) {
         QFile ytlink("/home/stuart/Videos/ytlink.ram");
