@@ -31,7 +31,6 @@ function showVideoDialog(index) {
         videoDialog.close.connect(closeDialogs);
         dimmer.state = "dim";
         videoDialog.state = "show";
-        mouseArea.enabled = true;
     }
 }
 
@@ -44,26 +43,27 @@ function showPlaylistDialog() {
             playlistDialog.close.connect(closeDialogs);
             dimmer.state = "dim";
             playlistDialog.state = "show";
-            mouseArea.enabled = true;
         }
         else {
-            displayMessage("You are not signed in to a YouTube account");
+            messages.messages.displayMessage(messages._NOT_SIGNED_IN);
         }
     }
 }
 
-function playVideo(playerUrl) {
-    YouTube.getVideoUrl(playerUrl);
-}
-
 function addVideosToPlaybackQueue() {
-    var list = [];
-    for (var i = 0; i < videoList.checkList.length; i++) {
-        var video = videoListModel.get(videoList.checkList[i]);
-        list.push(video);
+    if (videoList.checkList.length > 0) {
+        if (Controller.getMediaPlayer() == "cutetubeplayer") {
+            var list = [];
+            for (var i = 0; i < videoList.checkList.length; i++) {
+                list.push(videoListModel.get(videoList.checkList[i]));
+            }
+            playVideos(list);
+        }
+        else {
+            messages.messages.displayMessage(messages._USE_CUTETUBE_PLAYER);
+        }
+        videoList.checkList = [];
     }
-    videoList.checkList = [];
-    playVideos(list);
 }
 
 function addVideosToDownloads(convertToAudio) {
@@ -102,7 +102,7 @@ function deleteVideosFromPlaylist() {
         }
     }
     else {
-        displayMessage("You are not signed in to a YouTube account");
+        messages.messages.displayMessage(messages._NOT_SIGNED_IN);
     }
     videoList.checkList = [];
 }
@@ -118,7 +118,7 @@ function addVideosToFavourites() {
         }
     }
     else {
-        displayMessage("You are not signed in to a YouTube account");
+        messages.messages.displayMessage(messages._NOT_SIGNED_IN);
     }
     videoList.checkList = [];
 }
@@ -134,7 +134,7 @@ function deleteVideosFromFavourites() {
         }
     }
     else {
-        displayMessage("You are not signed in to a YouTube account");
+        messages.messages.displayMessage(messages._NOT_SIGNED_IN);
     }
     videoList.checkList = [];
 }
@@ -154,7 +154,6 @@ function closeDialogs() {
 
     dialogClose();
     dimmer.state = "";
-    mouseArea.enabled = false;
     toggleControls(true);
 }
 
@@ -169,7 +168,7 @@ function setSubscription() {
         }
     }
     else {
-        displayMessage("You are not signed in to a YouTube account");
+        messages.messages.displayMessage(messages._NOT_SIGNED_IN);
     }
     closeDialogs();
 }
